@@ -1,5 +1,7 @@
 from .screen import Screen
 from .chars import Chars
 from .sprite import Sprite
+from .vector import Vector
+from .texture import Texture
 
 from .readchar import wait_for_key
